@@ -1,18 +1,25 @@
 #!/usr/bin/env python
 
-#  Copyright 2014 Nokia Solutions and Networks Oyj
+#    Copyright 2014 Mikko Korpela
 #
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
+#    This file is part of Pabot - A parallel executor for Robot Framework test cases..
 #
-#      http://www.apache.org/licenses/LICENSE-2.0
+#    Pabot is free software: you can redistribute it and/or modify
+#    it under the terms of the GNU General Public License as published by
+#    the Free Software Foundation, either version 3 of the License, or
+#    (at your option) any later version.
 #
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
+#    Pabot is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU General Public License for more details.
+#
+#    You should have received a copy of the GNU General Public License
+#    along with Pabot.  If not, see <http://www.gnu.org/licenses/>.
+#
+#  partly based on work by Nokia Solutions and Networks Oyj
+#  that was licensed under Apache License Version 2.0
+
 
 import os, sys, time, datetime
 import multiprocessing
@@ -29,6 +36,7 @@ from multiprocessing.pool import ThreadPool
 from robot.run import USAGE
 from robot.utils import ArgumentParser
 import signal
+from result_merger import merge
 
 CTRL_C_PRESSED = False
 
@@ -174,12 +182,10 @@ def _options_for_dryrun(options, outs_dir):
         options['monitormarkers'] = 'off'
     return options
 
-def _options_for_rebot(options, datasources, start_time_string, end_time_string):
+def _options_for_rebot(options, start_time_string, end_time_string):
     rebot_options = options.copy()
-    rebot_options['name'] = options.get('name', ', '.join(datasources))
     rebot_options['starttime'] = start_time_string
     rebot_options['endtime'] = end_time_string
-    rebot_options['output'] = rebot_options.get('output', 'output.xml')
     rebot_options['monitorcolors'] = 'off'
     if ROBOT_VERSION >= '2.8':
         options['monitormarkers'] = 'off'
@@ -235,6 +241,13 @@ def _output_dir(options):
         shutil.rmtree(outpath)
     return outpath
 
+def _report_results(outs_dir, options, start_time_string):
+    output_path = os.path.abspath(os.path.join(options.get('outputdir', '.'), options.get('output', 'output.xml')))
+    merge(*sorted(glob(os.path.join(outs_dir, '**/*.xml')))).save(output_path)
+    print 'Output:  %s' % output_path
+    options['output'] = None # Do not write output again with rebot
+    return rebot(output_path, **_options_for_rebot(options, start_time_string, _now()))
+
 def main(args):
     start_time = time.time()
     start_time_string = _now()
@@ -244,8 +257,7 @@ def main(args):
         outs_dir = _output_dir(options)
         suite_names = solve_suite_names(outs_dir, datasources, options)
         _parallel_execute(datasources, options, outs_dir, pabot_args, suite_names)
-        sys.exit(rebot(*sorted(glob(os.path.join(outs_dir, '**/*.xml'))),
-                       **_options_for_rebot(options, datasources, start_time_string, _now())))
+        sys.exit(_report_results(outs_dir, options, start_time_string))
     except Information, i:
         print """A parallel executor for Robot Framework test cases.
 
@@ -258,7 +270,10 @@ more output
 RF script for situations where pybot is not used directly
 
 --processes [NUMBER OF PROCESSES]
-How many parallel executors to use (default max of 2 and cpu count)"""
+How many parallel executors to use (default max of 2 and cpu count)
+
+Copyright 2014 Mikko Korpela - GPLv3
+"""
         print i.message
     finally:
         _print_elapsed(start_time, time.time())
